YARP 2.3.10 (2011-08-19)                                              {#v2_3_10}
========================

Contributors
------------

This is a list of people that contributed to this release (generated from the
git history using `git shortlog -ens --no-merges v2.3.9...v2.3.10`):

```
     2  Lorenzo Natale <lorenzo.natale@iit.it>
     2  Paul Fitzpatrick <paulfitz@alum.mit.edu>
```
